@@ -315,11 +315,13 @@ class Join:
 class GroupBy:
     field: Field
 
+
 @dataclass
 class UnmatchedField:
-    name: str
-    type: str
-    filter: bool
+    value: str
+    confidence: str
+    type: Optional[str] = None
+
 
 @dataclass
 class Query:
