@@ -209,6 +209,7 @@ def check_button(response, comp = 0):
     return response.json()[0]['attachment']['body'][comp]['details']['label'], response.json()[0]['attachment']['body'][comp]['details']['link']
 
 
+## run the query test
 ## run the query test
 def run_test(query = '',
              n_cards = None, check_component_types = None, 
@@ -256,6 +257,14 @@ def run_test(query = '',
             
             failed_message += "<br><b>Card returned:</b> Could you be more specific?\n"
             
+        elif 'text' in response.json()[0]['attachment']['body'][0]['details'] and response.json()[0]['attachment']['body'][0]['details']['text'] == 'There are no cards in this channel. You can share existing cards on this channel, or create new ones using Feed Rules!':
+            
+            print('Card <There are no cards in this channel. You can share existing cards on this channel, or create new ones using Feed Rules!>')
+            
+            failed = True
+            
+            failed_message += "<br><b>Card returned:</b> There are no cards in this channel. You can share existing cards on this channel, or create new ones using Feed Rules!\n"
+            
         else:
             #check the number of cards
             if n_cards:
@@ -306,6 +315,8 @@ def run_test(query = '',
                 for position, columns in enumerate(check_table_columns):
 
                     if columns != []:  
+                        
+                  
 
                         if response.json()[0]['attachment']['body'][position]['component_type'] == 'table' and check_col_names(response, position) == set(columns):
 
