@@ -19,8 +19,10 @@ if __name__ == '__main__':
     condition5 = Condition(field5)
     sorting1 = Sorting("{{measure.A}}", SQLSorting.DESC)
     component = ChartComponent(type='chart', queryId="0", chartType='LINE')
-    query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3], where=[condition1, condition2, condition3, condition4, condition5],
-                   orderBy=[sorting1], limit=10, unmatched=[UnmatchedField(name="china", type="STRING", filter=False)])
+    query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3],
+                   where=[condition1, condition2, condition3, condition4, condition5],
+                   orderBy=[sorting1], limit=10,
+                   unmatched=[UnmatchedField(value="china", type="STRING", confidence="HIGH")])
     print(query1.to_sql())
     smartquery = SmartQuery(queries=[query1], components=[component])
     dump = jsons.dumps(smartquery)
